@@ -5,14 +5,20 @@ from bs4 import BeautifulSoup
 """
 https?://(racaty\.net/)\S+
 https://racaty.net/10w86dphf8y2
+https://racaty.io/10w86dphf8y2
+
 """
 
 def racaty_bypass(url: str)-> str:
         
-        url = url[:-1] if url[-1] == '/' else url
-        token = url.split("/")[-1]
+        
         
         client = requests.Session ()
+        url= client.get(url).url
+        
+        url = url[:-1] if url[-1] == '/' else url
+        token = url.split("/")[-1]
+              
         headers = {
 
             'content-type': 'application/x-www-form-urlencoded',
@@ -31,8 +37,9 @@ def racaty_bypass(url: str)-> str:
 
         response = client.post(url, headers=headers, data=data)
         soup = BeautifulSoup(response.text, "html.parser")  
+     
        
 
         if (btn := soup.find(class_="btn btn-dow")): return btn["href"]
         if (unique := soup.find(id="uniqueExpirylink")): return unique["href"]                                                         
-                       
+
